function [c,CORRH,CORRV,CORRD1,CORRD2]=runGBP(numNeib, nColors, nIters, Tstart, Tend, deltaT, SimHorizontal, SimVertical, ...
	     SimDiagonal1, SimDiagonal2)


% general parameters
thresh = 0.5; % threshold value for the correlations

% run GBP for each temperature
ind=1;clear c CORR*
c=cell(1,1);CORRH=c;CORRV=c;CORRD1=c;CORRD2=c;
for T=Tstart:deltaT:Tend
	disp(['begin GBP at T=',num2str(T)]);tm=clock;
	
	potH  = exp(-SimHorizontal/T);
	potV  = exp(-SimVertical/T);
	potD1 = exp(-SimDiagonal1/T);
	potD2 = exp(-SimDiagonal2/T);
	
	if numNeib==4
		[corrH, corrV] = ...
			gbpTypicalFast4(potH, potV, nIters, nColors);
	elseif numNeib==8
		[corrH, corrV, corrD1, corrD2] = ...
			gbpTypicalFast8(potH, potV, potD1, potD2, nIters, nColors);
	end
	
	tm=etime(clock,tm);
	disp(['finished GBP at T=',num2str(T),', elapsed time: ',num2str(tm)]);

	% postprocessing: threshold the correlations 
	if numNeib==4
		[c{ind}]=connectedComponents(2, thresh, corrH, corrV, [], []);
	elseif numNeib==8	
		[c{ind}]=connectedComponents(2, thresh, corrH, corrV, corrD1, corrD2);
	end
	
	CORRH{ind}=corrH;
	CORRV{ind}=corrV;
	if numNeib==8
	  CORRD1{ind}=corrD1;
	  CORRD2{ind}=corrD2;
	end
	
	
	ind=ind+1;
end



